=== added directory 'plugin/error_dictionary'
=== added file 'plugin/error_dictionary/dictionary.cc'
--- plugin/error_dictionary/dictionary.cc	1970-01-01 00:00:00 +0000
+++ plugin/error_dictionary/dictionary.cc	2010-12-16 00:11:51 +0000
@@ -0,0 +1,47 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Monty Taylor
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/error_dictionary/errors.h"
+
+namespace drizzle_plugin
+{
+
+static int init(drizzled::module::Context &context)
+{
+  context.add(new error_dictionary::Errors);
+  return 0;
+}
+
+}
+
+DRIZZLE_DECLARE_PLUGIN
+{
+  DRIZZLE_VERSION_ID,
+  "Error Dictionary",
+  "1.0",
+  "Monty Taylor",
+  "Data Dictionary for Errors.",
+  drizzled::PLUGIN_LICENSE_GPL,
+  drizzle_plugin::init,
+  NULL,
+  NULL
+}
+DRIZZLE_DECLARE_PLUGIN_END;

=== added file 'plugin/error_dictionary/errors.cc'
--- plugin/error_dictionary/errors.cc	1970-01-01 00:00:00 +0000
+++ plugin/error_dictionary/errors.cc	2010-12-16 00:11:51 +0000
@@ -0,0 +1,55 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Monty Taylor
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include "plugin/error_dictionary/errors.h"
+
+namespace drizzle_plugin
+{
+
+error_dictionary::Errors::Errors() :
+  drizzled::plugin::TableFunction("DATA_DICTIONARY", "ERRORS")
+{
+  add_field("ERROR_CODE", drizzled::plugin::TableFunction::NUMBER);
+  add_field("ERROR_NAME");
+  add_field("ERROR_MESSAGE");
+}
+
+error_dictionary::Errors::Generator::Generator(drizzled::Field **arg) :
+  drizzled::plugin::TableFunction::Generator(arg),
+  _error_map(drizzled::ErrorMap::get_error_message_map()),
+  _iter(drizzled::ErrorMap::get_error_message_map().begin())
+{ }
+
+bool error_dictionary::Errors::Generator::populate()
+{
+  if (_iter == _error_map.end())
+    return false;
+
+  push(uint64_t((*_iter).first));
+  push((*_iter).second.first);
+  push((*_iter).second.second);
+
+  ++_iter;
+  return true;
+}
+
+}

=== added file 'plugin/error_dictionary/errors.h'
--- plugin/error_dictionary/errors.h	1970-01-01 00:00:00 +0000
+++ plugin/error_dictionary/errors.h	2010-12-16 00:11:51 +0000
@@ -0,0 +1,58 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Monty Taylor
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_ERROR_DICTIONARY_ERRORS_H
+#define PLUGIN_ERROR_DICTIONARY_ERRORS_H
+
+#include <drizzled/plugin/table_function.h>
+#include <drizzled/error.h>
+
+namespace drizzle_plugin
+{
+namespace error_dictionary
+{
+
+class Errors :
+  public drizzled::plugin::TableFunction
+{
+public:
+  Errors();
+
+  class Generator :
+    public drizzled::plugin::TableFunction::Generator 
+  {
+    const drizzled::ErrorMap::ErrorMessageMap& _error_map;
+    drizzled::ErrorMap::ErrorMessageMap::const_iterator _iter;
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+};
+
+} /* namespace error_dictionary */
+} /* namespace drizzle_plugin */
+
+#endif /* PLUGIN_ERROR_DICTIONARY_ERRORS_H */

=== added file 'plugin/error_dictionary/plugin.ini'
--- plugin/error_dictionary/plugin.ini	1970-01-01 00:00:00 +0000
+++ plugin/error_dictionary/plugin.ini	2010-12-16 00:11:51 +0000
@@ -0,0 +1,10 @@
+[plugin]
+title=Error Code data dictionary tables.
+description=List the error codes and messages genearted by Drizzle.
+load_by_default=yes
+static=yes
+sources= 
+  dictionary.cc
+  errors.cc
+headers=
+  errors.h

=== added directory 'plugin/error_dictionary/tests'
=== added directory 'plugin/error_dictionary/tests/r'
=== added file 'plugin/error_dictionary/tests/r/main.result'
--- plugin/error_dictionary/tests/r/main.result	1970-01-01 00:00:00 +0000
+++ plugin/error_dictionary/tests/r/main.result	2010-12-16 00:11:51 +0000
@@ -0,0 +1,8 @@
+SELECT COUNT(ERROR_NAME) FROM DATA_DICTIONARY.ERRORS;
+COUNT(ERROR_NAME)
+#
+CREATE TABLE error_names SELECT ERROR_NAME FROM DATA_DICTIONARY.ERRORS;
+SELECT COUNT(*) FROM error_names;
+COUNT(*)
+#
+DROP TABLE error_names;

=== added directory 'plugin/error_dictionary/tests/t'
=== added file 'plugin/error_dictionary/tests/t/main.test'
--- plugin/error_dictionary/tests/t/main.test	1970-01-01 00:00:00 +0000
+++ plugin/error_dictionary/tests/t/main.test	2010-12-16 00:11:51 +0000
@@ -0,0 +1,12 @@
+--replace_column 1 #
+
+SELECT COUNT(ERROR_NAME) FROM DATA_DICTIONARY.ERRORS;
+
+CREATE TABLE error_names SELECT ERROR_NAME FROM DATA_DICTIONARY.ERRORS;
+
+--replace_column 1 #
+SELECT COUNT(*) FROM error_names;
+
+DROP TABLE error_names;
+
+

